/*********************************************************\
*  (C) 2005 VEMS Group                                    *
\*********************************************************/

// Type declarations global to everything

#ifndef GLOBAL_H
#define GLOBAL_H

#include <inttypes.h>
#include <avr/pgmspace.h>
#include <avr/interrupt.h>

// This will force all functions declared with INLINE to be inlined. No object
// code will ever be emitted.
#ifndef INLINE
#define INLINE extern inline 
#endif

struct config_t {	
	// EGT:
	uint8_t egt_cal;		// always appr. 153 
	uint8_t egt_offset;		// EGT offset; typical 64..192 (default: 192)

	uint8_t wbo2_pump_pw_zero;    // wbo2, pump zero dutycycle (default: 65) [5V/256]
	uint8_t wbo2_nernstdc_target; // wbo2, target nernstDC [5V/256]

  // measurement and controller
	uint8_t wbo2_ri_target;	// wbo2, target Ri (pulse amplitude:C3)[5V/4096]
	uint8_t wbo2_heater_pid_kp;   // wbo2, heater pid kp
	uint8_t wbo2_heater_pid_ki;   // wbo2, heater pid ki
	uint8_t wbo2_heater_pid_kd;   // wbo2, heater pid kd
	uint8_t wbo2_heater_pid_ilimit;   // wbo2, heater pid integral limit

	uint8_t wbo2_pump_pid_kp;   // wbo2, pump pid kp
	uint8_t wbo2_pump_pid_ki;   // wbo2, pump pid ki
	uint8_t wbo2_pump_pid_kd;   // wbo2, pump pid kd
	uint8_t wbo2_pump_pid_ilimit;   // wbo2, pump pid integral limit

	uint8_t wbo2_ri_confidence_scale;  // wbo2, Ri confidence scaling factor (s^2 < 255/scale)

	// WBO2 heater:
	uint8_t wbo2_warmup_ramp;     // wbo2, warmup ramp speed [3f=0.2V/sec]
	uint8_t wbo2_abs_limit;	// wbo2, heater absolute limit [2a=12V ff=30V]
	uint8_t wbo2_limit_maxt;     // wbo2, max time spent at abs_limit [262msec]
	uint8_t wbo2_fallback;     // wbo2, fallback V after maxt [1c=10V ff=30V]
	uint8_t wbo2_retry_t;     // wbo2, retry control after [4sec]

	// vout conf
	uint8_t vout_conf; // vout conf 0:EGT,1:NBO2,2:Ip,32..255:lambda linear out (156 = 3V/lamdba)

	// display state and scaling
	uint8_t afrmult;  		// lambda -> afr multiplier (147)
	uint8_t disp_state;   // last known display state
	uint8_t disp_dim;	// display dimming
	uint8_t disp_type;	// 0,2,4 for normal, HUD1, HUD2
	
	// boostcontrol and misc:
	uint8_t boost_channel;
	
	uint8_t rpm_toothcnt;	// 4cyl:2 6cyl:3 60-2:58
	uint8_t rpm_multiplier;	// currently unused (useful for wheelspeed ?)
};

extern struct config_t config;

#endif	// GLOBAL_H


